#
# spec file for package libmwaw
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libmwaw-0_3-3
Name:           libmwaw
Version:        0.3.6
Release:        2.5
Summary:        Pre Mac OSX text file formats parser library
License:        (LGPL-2.1+ or MPL-2.0) and GPL-2.0+
Group:          Productivity/Publishing/Word
Url:            http://sourceforge.net/p/libmwaw/wiki/Home/
Source:         http://downloads.sourceforge.net/project/%{name}/%{name}/%{name}-%{version}/%{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  librevenge-devel >= 0.0.0
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libmwaw is a project for converting many pre-OSX MAC text formats.

%package -n %{libname}
Summary:        Pre Mac OSX text file formats parser library
Group:          System/Libraries

%description -n %{libname}
Libmwaw is a new project for converting many pre-OSX MAC text formats.

%package devel
Summary:        Files for Developing with libmwaw
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       libwpd-devel

%description devel
Libmwaw is a new project for converting many pre-OSX MAC text formats.
This package contains the libmwaw development files.

%package devel-doc
Summary:        Documentation for the libmwaw API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libmwaw API.

%package tools
Summary:        Tools to work with publications in pre MAC OSX text file-formats
Group:          Productivity/Publishing/Word

%description tools
Command line tools to work with publications in pre MAC OSX text file-formats.

%prep
%setup -q
# doxygen needles rebuild
sed -i \
	-e 's:on $datetime::g' \
	docs/doxygen/footer.html.in

%build
autoreconf -fvi
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-silent-rules \
	--disable-werror \
	--disable-static \
	--docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
# documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -p COPYING.* %{buildroot}%{_docdir}/%{name}
# docs have duped pictures
%fdupes %{buildroot}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/libmwaw*.pc
%{_includedir}/libmwaw-*

%files devel-doc
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}/html

%files tools
%defattr(-,root,root)
%{_bindir}/*
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/[A-Z]*

%changelog
* Fri Aug 28 2015 tchvatal@suse.com
- Version bump to 0.3.6:
  - Added a minimal parser for ApplePict v1.v2, ie. no clipping, does not
    take in account the copy mode: srcCopy, srcOr, ...
  - Extended the --with-docs configure option to allow to build doc only
    for the API classes: --with-docs=no|api|full .
  - Added a parser for MacDraft v4-v5 documents.
  - RagTime v5-v6 parser: try to retrieve the main layouts and the
    picture/shape/textbox, ie. now, it generates result but it is
    still very imcomplete...
  - MWAW{Graphic,Presentation,Text}Listener: corrected a problem in openGroup
    which may create to incorrect document.
  - Created an MWAWEmbeddedObject class to store a picture with various
    representations.
  - MWAW*Listener: renamed insertPicture to insertShape, added a function to
    insert a texbox in a MWAWGraphicShape (which only insert a basic textbox).
  - Fixed many crashes and hangs when importing broken files, found with the
    help of american-fuzzy-lop.
  - And several other minor fixes and improvements.
* Sat Jun 13 2015 tchvatal@suse.com
- Version bump to 0.3.5
  * Various small fixes on 0.3 series, nothing big woth mention
* Fri Jan  2 2015 tchvatal@suse.com
- Version bump to 0.3.4:
  * Various tweaks&fixes on the 0.3 series found by fuzzy testing/etc
- Removed patch libmwaw-0.3.1-stream.patch as we should not bother
  with old autotools
* Tue Jul  1 2014 fstrba@suse.com
- Fix patch libmwaw-0.3.1-stream.patch to allow buiding with older
  version of autotools.
* Wed Jun 11 2014 tchvatal@suse.com
- Version bump to 0.3.1:
  * Switch over to librevenge framework
- Add patch libmwaw-0.3.1-stream.patch to fix streams
* Sat Jan 25 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and noarch documenation.
* Sat Jan 18 2014 crrodriguez@opensuse.org
- build with -fvisibility-inlines-hidden, around 2800
  less in the export symbol table.
* Tue Dec 17 2013 fridrich.strba@suse.com
- Upgrade to upstream 0.2.0
  - ABI change
  - Several improvements in handling of embedded graphics
* Tue Dec  3 2013 tchvatal@suse.com
- Format with spec-cleaner
* Fri Nov  1 2013 tchvatal@suse.com
- Drop doc conditional and use verbose build.
* Mon May 27 2013 tchvatal@suse.com
- Version bump to 0.1.9 providing following fixes:
  - improve a little the Microsoft Word filter to better manage
  character and paragraph properties
  - check that the remaining parsers (excepted Microsoft Word) use the
  new properties' classes,
  - add table generation in FullWrite parser,
  - rewrite from scratch zip.cpp (to avoid using different license),
  - + many code corrections done by David Tardon.
  - check that the WriterPlus parsers use the new properties' classes,
  - simplify a little the code of MWAWDocument
  - add a parser for Acta v2 and Acta Classic v1,
  - check that the DOCMaker, eDOC, SimpleText, Tex-Edit, Z-Write parsers
  use the new properties' classes,
  - rewrite MWAWPageSpan,
  - add classes MWAWField, MWAWNote, MWAWSection to store/manage
  field, note, section properties,
  - check that the ClarisWorks/AppleWorks, MacWrite, MindWrite,
  WriteNow parsers use the new properties' classes,
  - improve a little the ClarisWorks/AppleWorks frame position by
  placing <<correctly>> all page's frames,
  - MWAWContentListener : add a sanity check to insure that at most
  200 very small pictures are generated.
* Sun Apr 28 2013 fridrich.strba@suse.com
- Upgrade to upstream 0.1.8
  - Several improvements in different parsers
* Sat Apr 20 2013 tchvatal@suse.com
- Use download URL path.
* Tue Mar 26 2013 cfarrell@suse.com
- license update: (LGPL-2.1+ or MPL-2.0) and GPL-2.0+
  Most of package is dual MPL-2.0 or LGPL-2.1+ but tools/zip is GPL-2.0+
* Wed Mar 13 2013 tchvatal@suse.com
- Initial package of libmwaw. Required by libreoffice-4.1
